use actix_web::{web, Responder};
use sqlx::PgPool;

use crate::{
    endpoints::user::NewOrEditUserTemplate,
    utils::{ApplicationError, TemplateResponse},
};
use brass_db::models::{Area, Role, User};

#[actix_web::get("/users/new")]
pub async fn get_new(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
) -> Result<impl Responder, ApplicationError> {
    let mut areas: Option<Vec<Area>> = None;

    if user.role == Role::Admin {
        areas = Some(Area::read_all(pool.get_ref()).await?)
    }

    let template = NewOrEditUserTemplate {
        user: user.into_inner(),
        areas,
        id: None,
        email: None,
        name: None,
        role: None,
        is_posten: None,
        is_wachhabender: None,
        is_fuehrungsassistent: None,
        area_id: None,
    };

    Ok(template.to_response()?)
}
